==> huaweicloudsdkmetastudio-3.1.53-py2.py3-none-any.whl: huaweicloudsdkmetastudio/v1/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

from huaweicloudsdkmetastudio.v1.metastudio_client import MetaStudioClient
from huaweicloudsdkmetastudio.v1.metastudio_async_client import MetaStudioAsyncClient

from huaweicloudsdkmetastudio.v1.model.animation_asset_meta import AnimationAssetMeta
from huaweicloudsdkmetastudio.v1.model.animation_item import AnimationItem
from huaweicloudsdkmetastudio.v1.model.asset_extra_meta import AssetExtraMeta
from huaweicloudsdkmetastudio.v1.model.asset_file_info import AssetFileInfo
from huaweicloudsdkmetastudio.v1.model.component_info import ComponentInfo
from huaweicloudsdkmetastudio.v1.model.confirm_file_upload_request import ConfirmFileUploadRequest
from huaweicloudsdkmetastudio.v1.model.confirm_file_upload_request_body import ConfirmFileUploadRequestBody
from huaweicloudsdkmetastudio.v1.model.confirm_file_upload_response import ConfirmFileUploadResponse
from huaweicloudsdkmetastudio.v1.model.control_digital_human_live_req import ControlDigitalHumanLiveReq
from huaweicloudsdkmetastudio.v1.model.create_digital_asset_request import CreateDigitalAssetRequest
from huaweicloudsdkmetastudio.v1.model.create_digital_asset_request_body import CreateDigitalAssetRequestBody
from huaweicloudsdkmetastudio.v1.model.create_digital_asset_response import CreateDigitalAssetResponse
from huaweicloudsdkmetastudio.v1.model.create_file_request import CreateFileRequest
from huaweicloudsdkmetastudio.v1.model.create_file_response import CreateFileResponse
from huaweicloudsdkmetastudio.v1.model.create_picture_modeling_by_url_job_request import CreatePictureModelingByUrlJobRequest
from huaweicloudsdkmetastudio.v1.model.create_picture_modeling_by_url_job_response import CreatePictureModelingByUrlJobResponse
from huaweicloudsdkmetastudio.v1.model.create_picture_modeling_job_request import CreatePictureModelingJobRequest
from huaweicloudsdkmetastudio.v1.model.create_picture_modeling_job_request_body import CreatePictureModelingJobRequestBody
from huaweicloudsdkmetastudio.v1.model.create_picture_modeling_job_response import CreatePictureModelingJobResponse
from huaweicloudsdkmetastudio.v1.model.create_style_request_body import CreateStyleRequestBody
from huaweicloudsdkmetastudio.v1.model.create_ttsa_req import CreateTTSAReq
from huaweicloudsdkmetastudio.v1.model.create_ttsa_request import CreateTtsaRequest
from huaweicloudsdkmetastudio.v1.model.create_ttsa_response import CreateTtsaResponse
from huaweicloudsdkmetastudio.v1.model.create_video_motion_capture_job_request import CreateVideoMotionCaptureJobRequest
from huaweicloudsdkmetastudio.v1.model.create_video_motion_capture_job_response import CreateVideoMotionCaptureJobResponse
from huaweicloudsdkmetastudio.v1.model.delete_asset_request import DeleteAssetRequest
from huaweicloudsdkmetastudio.v1.model.delete_asset_response import DeleteAssetResponse
from huaweicloudsdkmetastudio.v1.model.delete_file_request import DeleteFileRequest
from huaweicloudsdkmetastudio.v1.model.delete_file_response import DeleteFileResponse
from huaweicloudsdkmetastudio.v1.model.digital_asset_info import DigitalAssetInfo
from huaweicloudsdkmetastudio.v1.model.digital_asset_summary import DigitalAssetSummary
from huaweicloudsdkmetastudio.v1.model.digital_human_modeling_job_info import DigitalHumanModelingJobInfo
from huaweicloudsdkmetastudio.v1.model.engine_asset_info import EngineAssetInfo
from huaweicloudsdkmetastudio.v1.model.error_response import ErrorResponse
from huaweicloudsdkmetastudio.v1.model.execute_video_motion_capture_command_request import ExecuteVideoMotionCaptureCommandRequest
from huaweicloudsdkmetastudio.v1.model.execute_video_motion_capture_command_response import ExecuteVideoMotionCaptureCommandResponse
from huaweicloudsdkmetastudio.v1.model.files_create_req import FilesCreateReq
from huaweicloudsdkmetastudio.v1.model.human_model_asset_meta import HumanModelAssetMeta
from huaweicloudsdkmetastudio.v1.model.human_model_meta_properties import HumanModelMetaProperties
from huaweicloudsdkmetastudio.v1.model.input_info import InputInfo
from huaweicloudsdkmetastudio.v1.model.list_asset_summary_request import ListAssetSummaryRequest
from huaweicloudsdkmetastudio.v1.model.list_asset_summary_response import ListAssetSummaryResponse
from huaweicloudsdkmetastudio.v1.model.list_asset_summarys_req import ListAssetSummarysReq
from huaweicloudsdkmetastudio.v1.model.list_assets_request import ListAssetsRequest
from huaweicloudsdkmetastudio.v1.model.list_assets_response import ListAssetsResponse
from huaweicloudsdkmetastudio.v1.model.list_picture_modeling_jobs_request import ListPictureModelingJobsRequest
from huaweicloudsdkmetastudio.v1.model.list_picture_modeling_jobs_response import ListPictureModelingJobsResponse
from huaweicloudsdkmetastudio.v1.model.list_styles_request import ListStylesRequest
from huaweicloudsdkmetastudio.v1.model.list_styles_response import ListStylesResponse
from huaweicloudsdkmetastudio.v1.model.list_ttsa_data_request import ListTtsaDataRequest
from huaweicloudsdkmetastudio.v1.model.list_ttsa_data_response import ListTtsaDataResponse
from huaweicloudsdkmetastudio.v1.model.list_ttsa_jobs_request import ListTtsaJobsRequest
from huaweicloudsdkmetastudio.v1.model.list_ttsa_jobs_response import ListTtsaJobsResponse
from huaweicloudsdkmetastudio.v1.model.list_video_motion_capture_jobs_request import ListVideoMotionCaptureJobsRequest
from huaweicloudsdkmetastudio.v1.model.list_video_motion_capture_jobs_response import ListVideoMotionCaptureJobsResponse
from huaweicloudsdkmetastudio.v1.model.material_asset_meta import MaterialAssetMeta
from huaweicloudsdkmetastudio.v1.model.material_component_info import MaterialComponentInfo
from huaweicloudsdkmetastudio.v1.model.motion_item import MotionItem
from huaweicloudsdkmetastudio.v1.model.output_info import OutputInfo
from huaweicloudsdkmetastudio.v1.model.ppt_asset_meta import PPTAssetMeta
from huaweicloudsdkmetastudio.v1.model.ppt_page_info import PPTPageInfo
from huaweicloudsdkmetastudio.v1.model.picture_modeling_by_url_req import PictureModelingByUrlReq
from huaweicloudsdkmetastudio.v1.model.picture_modeling_info import PictureModelingInfo
from huaweicloudsdkmetastudio.v1.model.rtc_room_info_list import RTCRoomInfoList
from huaweicloudsdkmetastudio.v1.model.rtc_user_info import RTCUserInfo
from huaweicloudsdkmetastudio.v1.model.restore_asset_request import RestoreAssetRequest
from huaweicloudsdkmetastudio.v1.model.restore_asset_response import RestoreAssetResponse
from huaweicloudsdkmetastudio.v1.model.scene_asset_meta import SceneAssetMeta
from huaweicloudsdkmetastudio.v1.model.scene_component_info import SceneComponentInfo
from huaweicloudsdkmetastudio.v1.model.show_asset_request import ShowAssetRequest
from huaweicloudsdkmetastudio.v1.model.show_asset_response import ShowAssetResponse
from huaweicloudsdkmetastudio.v1.model.show_picture_modeling_job_request import ShowPictureModelingJobRequest
from huaweicloudsdkmetastudio.v1.model.show_picture_modeling_job_response import ShowPictureModelingJobResponse
from huaweicloudsdkmetastudio.v1.model.show_video_motion_capture_job_request import ShowVideoMotionCaptureJobRequest
from huaweicloudsdkmetastudio.v1.model.show_video_motion_capture_job_response import ShowVideoMotionCaptureJobResponse
from huaweicloudsdkmetastudio.v1.model.stop_video_motion_capture_job_request import StopVideoMotionCaptureJobRequest
from huaweicloudsdkmetastudio.v1.model.stop_video_motion_capture_job_response import StopVideoMotionCaptureJobResponse
from huaweicloudsdkmetastudio.v1.model.style_asset_item import StyleAssetItem
from huaweicloudsdkmetastudio.v1.model.style_extra_meta import StyleExtraMeta
from huaweicloudsdkmetastudio.v1.model.style_extra_meta_additional_properties import StyleExtraMetaAdditionalProperties
from huaweicloudsdkmetastudio.v1.model.style_extra_meta_additional_properties1 import StyleExtraMetaAdditionalProperties1
from huaweicloudsdkmetastudio.v1.model.style_extra_meta_edit_color_items import StyleExtraMetaEditColorItems
from huaweicloudsdkmetastudio.v1.model.style_extra_meta_edit_components import StyleExtraMetaEditComponents
from huaweicloudsdkmetastudio.v1.model.style_extra_meta_edit_value_items import StyleExtraMetaEditValueItems
from huaweicloudsdkmetastudio.v1.model.style_extra_meta_modelling_algorithm import StyleExtraMetaModellingAlgorithm
from huaweicloudsdkmetastudio.v1.model.style_info import StyleInfo
from huaweicloudsdkmetastudio.v1.model.system_property import SystemProperty
from huaweicloudsdkmetastudio.v1.model.ttsa_job import TTSAJob
from huaweicloudsdkmetastudio.v1.model.update_digital_asset_request import UpdateDigitalAssetRequest
from huaweicloudsdkmetastudio.v1.model.update_digital_asset_request_body import UpdateDigitalAssetRequestBody
from huaweicloudsdkmetastudio.v1.model.update_digital_asset_response import UpdateDigitalAssetResponse
from huaweicloudsdkmetastudio.v1.model.video_motion_capture_info import VideoMotionCaptureInfo
from huaweicloudsdkmetastudio.v1.model.video_motion_capture_job_req import VideoMotionCaptureJobReq
from huaweicloudsdkmetastudio.v1.model.voice_model_asset_meta import VoiceModelAssetMeta

==> huaweicloudsdkmetastudio-3.1.57-py2.py3-none-any.whl: huaweicloudsdkmetastudio/v1/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

from huaweicloudsdkmetastudio.v1.metastudio_client import MetaStudioClient
from huaweicloudsdkmetastudio.v1.metastudio_async_client import MetaStudioAsyncClient

from huaweicloudsdkmetastudio.v1.model.animation_asset_meta import AnimationAssetMeta
from huaweicloudsdkmetastudio.v1.model.animation_item import AnimationItem
from huaweicloudsdkmetastudio.v1.model.asset_extra_meta import AssetExtraMeta
from huaweicloudsdkmetastudio.v1.model.asset_file_info import AssetFileInfo
from huaweicloudsdkmetastudio.v1.model.component_info import ComponentInfo
from huaweicloudsdkmetastudio.v1.model.confirm_file_upload_request import ConfirmFileUploadRequest
from huaweicloudsdkmetastudio.v1.model.confirm_file_upload_request_body import ConfirmFileUploadRequestBody
from huaweicloudsdkmetastudio.v1.model.confirm_file_upload_response import ConfirmFileUploadResponse
from huaweicloudsdkmetastudio.v1.model.control_digital_human_live_req import ControlDigitalHumanLiveReq
from huaweicloudsdkmetastudio.v1.model.create_digital_asset_request import CreateDigitalAssetRequest
from huaweicloudsdkmetastudio.v1.model.create_digital_asset_request_body import CreateDigitalAssetRequestBody
from huaweicloudsdkmetastudio.v1.model.create_digital_asset_response import CreateDigitalAssetResponse
from huaweicloudsdkmetastudio.v1.model.create_file_request import CreateFileRequest
from huaweicloudsdkmetastudio.v1.model.create_file_response import CreateFileResponse
from huaweicloudsdkmetastudio.v1.model.create_picture_modeling_by_url_job_request import CreatePictureModelingByUrlJobRequest
from huaweicloudsdkmetastudio.v1.model.create_picture_modeling_by_url_job_response import CreatePictureModelingByUrlJobResponse
from huaweicloudsdkmetastudio.v1.model.create_picture_modeling_job_request import CreatePictureModelingJobRequest
from huaweicloudsdkmetastudio.v1.model.create_picture_modeling_job_request_body import CreatePictureModelingJobRequestBody
from huaweicloudsdkmetastudio.v1.model.create_picture_modeling_job_response import CreatePictureModelingJobResponse
from huaweicloudsdkmetastudio.v1.model.create_style_request_body import CreateStyleRequestBody
from huaweicloudsdkmetastudio.v1.model.create_ttsa_req import CreateTTSAReq
from huaweicloudsdkmetastudio.v1.model.create_ttsa_request import CreateTtsaRequest
from huaweicloudsdkmetastudio.v1.model.create_ttsa_response import CreateTtsaResponse
from huaweicloudsdkmetastudio.v1.model.create_video_motion_capture_job_request import CreateVideoMotionCaptureJobRequest
from huaweicloudsdkmetastudio.v1.model.create_video_motion_capture_job_response import CreateVideoMotionCaptureJobResponse
from huaweicloudsdkmetastudio.v1.model.delete_asset_request import DeleteAssetRequest
from huaweicloudsdkmetastudio.v1.model.delete_asset_response import DeleteAssetResponse
from huaweicloudsdkmetastudio.v1.model.delete_file_request import DeleteFileRequest
from huaweicloudsdkmetastudio.v1.model.delete_file_response import DeleteFileResponse
from huaweicloudsdkmetastudio.v1.model.digital_asset_info import DigitalAssetInfo
from huaweicloudsdkmetastudio.v1.model.digital_asset_summary import DigitalAssetSummary
from huaweicloudsdkmetastudio.v1.model.digital_human_modeling_job_info import DigitalHumanModelingJobInfo
from huaweicloudsdkmetastudio.v1.model.error_response import ErrorResponse
from huaweicloudsdkmetastudio.v1.model.execute_video_motion_capture_command_request import ExecuteVideoMotionCaptureCommandRequest
from huaweicloudsdkmetastudio.v1.model.execute_video_motion_capture_command_response import ExecuteVideoMotionCaptureCommandResponse
from huaweicloudsdkmetastudio.v1.model.files_create_req import FilesCreateReq
from huaweicloudsdkmetastudio.v1.model.human_model2_d_asset_meta import HumanModel2DAssetMeta
from huaweicloudsdkmetastudio.v1.model.human_model_asset_meta import HumanModelAssetMeta
from huaweicloudsdkmetastudio.v1.model.human_model_meta_properties import HumanModelMetaProperties
from huaweicloudsdkmetastudio.v1.model.input_info import InputInfo
from huaweicloudsdkmetastudio.v1.model.list_asset_summary_request import ListAssetSummaryRequest
from huaweicloudsdkmetastudio.v1.model.list_asset_summary_response import ListAssetSummaryResponse
from huaweicloudsdkmetastudio.v1.model.list_asset_summarys_req import ListAssetSummarysReq
from huaweicloudsdkmetastudio.v1.model.list_assets_request import ListAssetsRequest
from huaweicloudsdkmetastudio.v1.model.list_assets_response import ListAssetsResponse
from huaweicloudsdkmetastudio.v1.model.list_picture_modeling_jobs_request import ListPictureModelingJobsRequest
from huaweicloudsdkmetastudio.v1.model.list_picture_modeling_jobs_response import ListPictureModelingJobsResponse
from huaweicloudsdkmetastudio.v1.model.list_styles_request import ListStylesRequest
from huaweicloudsdkmetastudio.v1.model.list_styles_response import ListStylesResponse
from huaweicloudsdkmetastudio.v1.model.list_ttsa_data_request import ListTtsaDataRequest
from huaweicloudsdkmetastudio.v1.model.list_ttsa_data_response import ListTtsaDataResponse
from huaweicloudsdkmetastudio.v1.model.list_ttsa_jobs_request import ListTtsaJobsRequest
from huaweicloudsdkmetastudio.v1.model.list_ttsa_jobs_response import ListTtsaJobsResponse
from huaweicloudsdkmetastudio.v1.model.list_video_motion_capture_jobs_request import ListVideoMotionCaptureJobsRequest
from huaweicloudsdkmetastudio.v1.model.list_video_motion_capture_jobs_response import ListVideoMotionCaptureJobsResponse
from huaweicloudsdkmetastudio.v1.model.material_asset_meta import MaterialAssetMeta
from huaweicloudsdkmetastudio.v1.model.material_component_info import MaterialComponentInfo
from huaweicloudsdkmetastudio.v1.model.motion_item import MotionItem
from huaweicloudsdkmetastudio.v1.model.output_info import OutputInfo
from huaweicloudsdkmetastudio.v1.model.ppt_asset_meta import PPTAssetMeta
from huaweicloudsdkmetastudio.v1.model.ppt_page_info import PPTPageInfo
from huaweicloudsdkmetastudio.v1.model.picture_modeling_by_url_req import PictureModelingByUrlReq
from huaweicloudsdkmetastudio.v1.model.picture_modeling_info import PictureModelingInfo
from huaweicloudsdkmetastudio.v1.model.rtc_room_info_list import RTCRoomInfoList
from huaweicloudsdkmetastudio.v1.model.rtc_user_info import RTCUserInfo
from huaweicloudsdkmetastudio.v1.model.restore_asset_request import RestoreAssetRequest
from huaweicloudsdkmetastudio.v1.model.restore_asset_response import RestoreAssetResponse
from huaweicloudsdkmetastudio.v1.model.scene_asset_meta import SceneAssetMeta
from huaweicloudsdkmetastudio.v1.model.scene_component_info import SceneComponentInfo
from huaweicloudsdkmetastudio.v1.model.show_asset_request import ShowAssetRequest
from huaweicloudsdkmetastudio.v1.model.show_asset_response import ShowAssetResponse
from huaweicloudsdkmetastudio.v1.model.show_picture_modeling_job_request import ShowPictureModelingJobRequest
from huaweicloudsdkmetastudio.v1.model.show_picture_modeling_job_response import ShowPictureModelingJobResponse
from huaweicloudsdkmetastudio.v1.model.show_video_motion_capture_job_request import ShowVideoMotionCaptureJobRequest
from huaweicloudsdkmetastudio.v1.model.show_video_motion_capture_job_response import ShowVideoMotionCaptureJobResponse
from huaweicloudsdkmetastudio.v1.model.stop_video_motion_capture_job_request import StopVideoMotionCaptureJobRequest
from huaweicloudsdkmetastudio.v1.model.stop_video_motion_capture_job_response import StopVideoMotionCaptureJobResponse
from huaweicloudsdkmetastudio.v1.model.style_asset_item import StyleAssetItem
from huaweicloudsdkmetastudio.v1.model.style_extra_meta import StyleExtraMeta
from huaweicloudsdkmetastudio.v1.model.style_info import StyleInfo
from huaweicloudsdkmetastudio.v1.model.system_property import SystemProperty
from huaweicloudsdkmetastudio.v1.model.ttsa_job import TTSAJob
from huaweicloudsdkmetastudio.v1.model.update_digital_asset_request import UpdateDigitalAssetRequest
from huaweicloudsdkmetastudio.v1.model.update_digital_asset_request_body import UpdateDigitalAssetRequestBody
from huaweicloudsdkmetastudio.v1.model.update_digital_asset_response import UpdateDigitalAssetResponse
from huaweicloudsdkmetastudio.v1.model.video_motion_capture_info import VideoMotionCaptureInfo
from huaweicloudsdkmetastudio.v1.model.video_motion_capture_job_req import VideoMotionCaptureJobReq
from huaweicloudsdkmetastudio.v1.model.voice_model_asset_meta import VoiceModelAssetMeta
